Package: GEOquery
Type: Package
Title: Get data from NCBI Gene Expression Omnibus (GEO)
Version: 2.80.0
Date: 2025-09-03
Authors@R: 
  c(person(given = "Sean",
           family = "Davis",
           role = c("aut", "cre"),
           email = "seandavi@gmail.com",
           comment = c(ORCID = "0000-0002-8991-6458")))
BugReports: https://github.com/seandavi/GEOquery/issues/new
Depends: R (>= 4.1.0), methods, Biobase
Imports: readr (>= 1.3.1), xml2, dplyr, data.table, tidyr, magrittr,
        limma, curl, rentrez, R.utils, stringr, SummarizedExperiment,
        S4Vectors, rvest, httr2
Suggests: knitr, rmarkdown, BiocGenerics, testthat, covr, markdown,
        quarto, DropletUtils, SingleCellExperiment
VignetteBuilder: quarto
URL: https://github.com/seandavi/GEOquery,
        http://seandavi.github.io/GEOquery,
        http://seandavi.github.io/GEOquery/
biocViews: Microarray, DataImport, OneChannel, TwoChannel, SAGE
Description: The NCBI Gene Expression Omnibus (GEO) is a public repository of microarray data.  Given the rich and varied nature of this resource, it is only natural to want to apply BioConductor tools to these data.  GEOquery is the bridge between GEO and BioConductor.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Roxygen: list(markdown = TRUE)
git_url: https://git.bioconductor.org/packages/GEOquery
git_branch: RELEASE_3_23
git_last_commit: 8b846af
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:18:19 UTC; biocbuild
Author: Sean Davis [aut, cre] (ORCID: <https://orcid.org/0000-0002-8991-6458>)
Maintainer: Sean Davis <seandavi@gmail.com>
