# Generated by roxygen2: do not edit by hand

export(GDS2MA)
export(GDS2eSet)
export(browseGEOAccession)
export(browseWebsiteRNASeqSearch)
export(getGEO)
export(getGEOSeriesFileListing)
export(getGEOSuppFileURL)
export(getGEOSuppFiles)
export(getGEOfile)
export(getGSEDataTables)
export(getRNASeqData)
export(getRNASeqQuantGenomeInfo)
export(hasRNASeqQuantifications)
export(parseGEO)
export(searchFieldsGEO)
export(searchGEO)
export(urlForAccession)
exportMethods(Accession)
exportMethods(Columns)
exportMethods(GPL)
exportMethods(GPLList)
exportMethods(GSMList)
exportMethods(Meta)
exportMethods(Table)
exportMethods(dataTable)
exportMethods(show)
import(SummarizedExperiment)
import(rentrez)
importClassesFrom(Biobase,ExpressionSet)
importClassesFrom(limma,MAList)
importFrom(data.table,fread)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,select)
importFrom(magrittr,"%>%")
importFrom(readr,problems)
importFrom(readr,read_lines)
importFrom(readr,read_tsv)
importFrom(tidyr,gather)
importFrom(tidyr,separate)
importFrom(tidyr,spread)
importFrom(utils,download.file)
importFrom(xml2,read_html)
importFrom(xml2,read_xml)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_text)
