% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rnaseq.R
\name{browseWebsiteRNASeqSearch}
\alias{browseWebsiteRNASeqSearch}
\title{Browse GEO search website for RNA-seq datasets}
\usage{
browseWebsiteRNASeqSearch()
}
\description{
This function opens a browser window to the NCBI GEO website
with a search for RNA-seq datasets. It is included as a convenience
function to remind users of how to search for RNA-seq datasets using
the NCBI GEO website and an "rnaseq counts" filter.
}
\examples{
\dontrun{
browseWebsiteRNASeqSearch()
}
}
