% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rnaseq.R
\name{readRNAQuantRawCounts}
\alias{readRNAQuantRawCounts}
\title{Read raw counts from GEO}
\usage{
readRNAQuantRawCounts(link)
}
\arguments{
\item{link}{A link to the raw counts file}
}
\value{
A matrix of raw counts with gene IDs as row names
}
\description{
This function reads the raw counts from a GEO link. The raw counts
are expected to be in a tab-separated file with the first column
containing the gene IDs and the remaining columns containing the
raw counts.
}
\details{
This function reads the raw counts and returns a matrix with the
gene IDs as the row names, ready for use in creating a
SummarizedExperiment.
}
\keyword{internal}
